SystemOrganization addCategory: #ConfigurationOfStoryBoard!

Object subclass: #ConfigurationOfStoryBoard
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfStoryBoard'!

!ConfigurationOfStoryBoard commentStamp: 'DiegoLont 8/9/2012 15:43' prior: 0!
The following load expression will load the 'default' group for StoryBoard:

   (ConfigurationOfStoryBoard project version: '0.1') load.

   alternatively you can also load the stable version using:
	 (ConfigurationOfStoryBoard project version: #stable) load.

By default all of the packages and projects associated with the StoryBoard 
project will be loaded!

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfStoryBoard class methodsFor: 'private' stamp: 'DiegoLont 8/9/2012 15:25'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfStoryBoard class methodsFor: 'private' stamp: 'DiegoLont 8/9/2012 15:25'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfStoryBoard class methodsFor: 'metacello tool support' stamp: 'DiegoLont 8/9/2012 15:25'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfStoryBoard class methodsFor: 'metacello tool support' stamp: 'DiegoLont 8/9/2012 15:25'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfStoryBoard class methodsFor: 'loading' stamp: 'DiegoLont 8/9/2012 15:25'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfStoryBoard class methodsFor: 'loading' stamp: 'DiegoLont 8/9/2012 15:25'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfStoryBoard class methodsFor: 'metacello tool support' stamp: 'DiegoLont 8/9/2012 15:25'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfStoryBoard class methodsFor: 'accessing' stamp: 'DiegoLont 8/9/2012 15:25'!
project

	^self new project! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfStoryBoard class methodsFor: 'development support' stamp: 'DiegoLont 8/9/2012 15:25'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfStoryBoard methodsFor: 'baselines' stamp: 'DiegoLont 8/26/2012 13:04'!
baseline010: spec 
	<version: '0.1.0-baseline'>

	spec for: #common do: [
		spec blessing: #'development'.
		spec description: '- first uploaded version'.
		spec project: 'Deltawerken' with: [ 
			spec 
				className: 'ConfigurationOfDeltawerken';
				versionString: #'development';
				loads: #( 'Seaside' );
				repository: 'http://ss3.gemstone.com/ss/Deltawerken' ].
		spec
			repository: 'http://ss3.gemstone.com/ss/StoryBoard';
			package: 'StoryBoard' with: [ spec requires: #( 'Deltawerken' ) ];
			group: 'default' with: #('Core' );
			group: 'Core' with: #('StoryBoard');
			yourself ]! !

!ConfigurationOfStoryBoard methodsFor: 'symbolic versions' stamp: 'DiegoLont 8/9/2012 15:36'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '0.1.0-baseline'.
! !

!ConfigurationOfStoryBoard methodsFor: 'symbolic versions' stamp: 'DiegoLont 8/9/2012 15:25'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfStoryBoard methodsFor: 'accessing' stamp: 'DiegoLont 8/9/2012 15:25'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		projectAttributes := projectAttributes, ((Smalltalk at: #OBNode ifAbsent: []) == nil
			ifTrue: [ #( #'OBNotPresent' ) ]
			ifFalse: [ #( #'OBPresent' ) ]).
		projectAttributes := projectAttributes, ((Smalltalk at: #ParseTreeEnvironment ifAbsent: []) == nil
			ifTrue: [ #( #'RBNotPresent' ) ]
			ifFalse: [ #( #'RBPresent' ) ]).
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfStoryBoard methodsFor: 'symbolic versions' stamp: 'DiegoLont 8/9/2012 15:37'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.1'.
! !

!ConfigurationOfStoryBoard methodsFor: 'versions' stamp: 'DiegoLont 8/26/2012 12:58'!
version010: spec
	<version: '0.1.0' imports: #('0.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'First uploaded version'.
		spec author: 'Diego Lont'.
		spec timestamp: '26/08/2012'.
		spec
			package: 'StoryBoard-Data' with: 'StoryBoard-DiegoLont.68' ]! !
